@@ -12,34 +12,31 @@ class ScrollableFrame(Frame):
         super().__init__(container, *args, **kwargs)
         top_frame =Frame( self)
         bottom_frame = Frame( self )
-        self.canvas = Canvas(top_frame)
-        self.frame =Frame(self.canvas)
-
-        self.canvas['width'] = kwargs['width']
-        self.canvas['height'] = kwargs['height']
+        canvas = Canvas(top_frame,*args, **kwargs)
+        self.frame =Frame(canvas)
 
         scrollbar = Scrollbar(top_frame if orient==0 else bottom_frame, \
-        command=self.canvas.yview if orient==0 else self.canvas.xview, orient=VERTICAL \
+        command=canvas.yview if orient==0 else canvas.xview, orient=VERTICAL \
         if orient== 0 else HORIZONTAL)
         if orient == 0:
-            self.canvas.configure(yscrollcommand=scrollbar.set)
+            canvas.configure(yscrollcommand=scrollbar.set)
         else:
-            self.canvas.configure(xscrollcommand=scrollbar.set)
+            canvas.configure(xscrollcommand=scrollbar.set)
         if orient == 2:
-            _scrollbar = Scrollbar(self,  command=self.canvas.yview, orient=VERTICAL)
-            self.canvas.configure(yscrollcommand=_scrollbar.set)
+            _scrollbar = Scrollbar(self,  command=canvas.yview, orient=VERTICAL)
+            canvas.configure(yscrollcommand=_scrollbar.set)
             _scrollbar.pack(side=RIGHT, fill=Y  )
 
-        self.canvas.create_window((0, 0), window=self.frame, anchor=NW)
+        canvas.create_window((0, 0), window=self.frame, anchor=NW)
 
         self.frame.bind(
             "<Configure>",
-            lambda e: self.canvas.configure(
-                scrollregion=self.canvas.bbox("all")
+            lambda e: canvas.configure(
+                scrollregion=canvas.bbox("all")
             )
         )
 
-        self.canvas.pack(side=LEFT, fill=BOTH, expand=True)
+        canvas.pack(side=LEFT, fill=BOTH, expand=True)
         scrollbar.pack(side=RIGHT if orient==0 else BOTTOM, \
         fill=Y if orient==0 else X )
         top_frame.pack(side=TOP)
